==> taler-wallet-v0.9.4a.tar.gz: taler-wallet-v0.9.4a/packages/merchant-backoffice-ui/src/paths/admin/create/Create.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2023 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { h, VNode, FunctionalComponent } from "preact";
import { ConfigContextProvider } from "../../../context/config.js";
import { CreatePage as TestedComponent } from "./CreatePage.js";

export default {
  title: "Pages/Instance/Create",
  component: TestedComponent,
  argTypes: {
    onCreate: { action: "onCreate" },
    goBack: { action: "goBack" },
  },
};

function createExample<Props>(
  Component: FunctionalComponent<Props>,
  props: Partial<Props>,
) {
  const r = (args: any) => (
    <ConfigContextProvider
      value={{
        currency: "ARS",
        version: "1",
        currencies: {
          currency: "TESTKUDOS"
        },
        exchanges: [],
        name: "taler-merchant"
      }}
    >
      <Component {...args} />
    </ConfigContextProvider>
  );
  r.args = props;
  return r;
}

export const Example = createExample(TestedComponent, {});
// export const Example = (a: any): VNode => <CreatePage {...a} />;
// Example.args = {
//   isLoading: false
// }

==> taler-wallet-v0.12.7.tar.gz: taler-wallet-v0.12.7/packages/merchant-backoffice-ui/src/paths/admin/create/Create.stories.tsx <==
/*
 This file is part of GNU Taler
 (C) 2021-2024 Taler Systems S.A.

 GNU Taler is free software; you can redistribute it and/or modify it under the
 terms of the GNU General Public License as published by the Free Software
 Foundation; either version 3, or (at your option) any later version.

 GNU Taler is distributed in the hope that it will be useful, but WITHOUT ANY
 WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR
 A PARTICULAR PURPOSE.  See the GNU General Public License for more details.

 You should have received a copy of the GNU General Public License along with
 GNU Taler; see the file COPYING.  If not, see <http://www.gnu.org/licenses/>
 */

/**
 *
 * @author Sebastian Javier Marchano (sebasjm)
 */

import { MerchantApiProviderTesting } from "@gnu-taler/web-util/browser";
import { FunctionalComponent, h } from "preact";
import { CreatePage as TestedComponent } from "./CreatePage.js";

export default {
  title: "Pages/Instance/Create",
  component: TestedComponent,
  argTypes: {
    onCreate: { action: "onCreate" },
    goBack: { action: "goBack" },
  },
};

function createExample<Props>(
  Component: FunctionalComponent<Props>,
  props: Partial<Props>,
) {
  const r = (args: any) => (
    <MerchantApiProviderTesting
      value={{
        cancelRequest: () => {},
        changeBackend: () => {},
        config: {
          currency: "ARS",
          version: "1",
          currencies: {
            "ASD": {
              name: "testkudos",
              alt_unit_names: {},
              num_fractional_input_digits: 1,
              num_fractional_normal_digits: 1,
              num_fractional_trailing_zero_digits: 1,
            }
          },
          exchanges: [],
          name: "taler-merchant"
        },
        hints: [],
        lib: {} as any,
        onActivity: (() => {}) as any,
        url: new URL("asdasd"),
      }}
    >
      <Component {...args} />
    </MerchantApiProviderTesting>
  );
  r.args = props;
  return r;
}

export const Example = createExample(TestedComponent, {});
// export const Example = (a: any): VNode => <CreatePage {...a} />;
// Example.args = {
//   isLoading: false
// }
